function [OutCellArray, Outconfig] = MapContourPlot(InCellArray, Inconfig)
%Description: Contour plot of a map, with n contour levels (n is user
%specified).  User can select grid on or grid off
%
%Inputs: Map
%Outputs: Map
%
%Author: Melanie Saayman
%Email: melanies@optics.arizona.edu
%
% Version history:
% 10/04/10 - Version 1
% 10/18/10 - Version 2
% 8/20/11 - version 2.1 by Dae Wook Kim letter2dwk@hotmail.com (unit for Z
% value)

OutCellArray{1} = InCellArray{1};
Outconfig = Inconfig;

% Make sure units are the same before running module.
xunit = InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Unit'),2};
yunit = InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Unit'),2};
zunit = InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Z Unit'),2};

if(xunit ~= yunit) 
    msgbox('Please check that X Unit and Y Unit match in the header of the Map.','Invalid Units','warn','modal');
    return;
end

RadiusX=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Size'),2})/2;
RadiusY=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Size'),2})/2;

nlevels = Inconfig{strcmpi(Inconfig, 'No. of contour levels'),2};
InitSelection = Inconfig{strcmpi(Inconfig, 'Grid'),2};

validinputs = 0;

% Get inputs
while ~validinputs
    answers = inputdlg({'No. of contour levels'},'MapContourPlot',1,{num2str(nlevels)});
    if ~isempty(answers)
        tmp_nlevels = answers{1};              
        tmp_nlevels = str2double(tmp_nlevels);

        if ~isempty(tmp_nlevels) && isnumeric(tmp_nlevels)
            validinputs = 1;             
            nlevels = tmp_nlevels;
        else
            msgbox('Please enter valid inputs','Invalid Inputs','warn','modal')
        end
    else
        OutCellArray = {};
        return; % If answers is empty, user canceled
    end
end

switch InitSelection
    case 'on'
        InitSelection = 1;
    case 'off'
        InitSelection = 2;
    otherwise
        InitSelection = 1;
end

[selection, ok] = listdlg('Name', 'MapContourPlot', 'PromptString','Select grid on or off:', ...
    'SelectionMode','single','ListString',{'Grid on', 'Grid off'}, 'InitialValue', InitSelection);

if ~ok, return; end % user canceled

x = linspace(-RadiusX, RadiusX, length(InCellArray{1}.data));
y = linspace(-RadiusY, RadiusY, length(InCellArray{1}.data));

figure
contour(x,y,InCellArray{1}.data,nlevels)
colorbar
title(['Contour Plot[', zunit,']']);
xlabel(['[',xunit,']']);
ylabel(['[',yunit,']']);
axis square;

switch selection % execute grid selection
    case 1
        Grid = 'on';
        grid on
    case 2
        Grid = 'off';
        grid off
    otherwise
        Grid = 'on';
        grid on       
end

Outconfig{strcmpi(Outconfig, 'No. of contour levels'),2} = num2str(nlevels);
Outconfig{strcmpi(Outconfig, 'Grid'),2} = num2str(Grid);

end

