function [OutCellArray, Outconfig]=RadCoords2Map(InCellArray, Inconfig)
%RadCoords2Map generates a map from a radial section.  Data is assumed to
%be in Rho, Z order. 
%
%Inputs: Coordinates
%Outputs: Map
%
%Author: Benjamin Lewis
%Email: blewis@email.arizona.edu
%
% Version history:
% 8/20/11 - Version 1.1 Dae Wook Kim letter2dwk@hotmail.com (put the module 
% description)
% 1/12/12 - Version 1.2 (Added support for new datatypes, algorithm
% tweaks)


Outconfig=Inconfig;

pts=Inconfig{strcmpi(Inconfig, 'pts'),2};

validinputs=0;

%Get inputs
while ~validinputs
    answers = inputdlg({'Data Points for Reconstruction'},'RadCoords2Map',1,{pts});
    if ~isempty(answers)
        temppts=answers{1};              
        temppts=str2double(temppts);

        if ~isempty(temppts)&&isnumeric(temppts)
            validinputs=1;             
            pts=temppts;
        else
            msgbox('Please enter valid inputs','Invalid Inputs','warn','modal')
        end
    else
        OutCellArray={};
        return; %If answers is empty, user canceled
    end
end

Outconfig{strcmpi(Outconfig, 'pts'),2}=num2str(pts);



OutCellArray{1}=InCellArray{1};

units=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Column Unit'),2};

units=regexp(units,', ','split');

xu=units{1};
zu=units{2};
yu=xu;

xprof=InCellArray{1}.data(:,1);
zprof=InCellArray{1}.data(:,2);




OutCellArray{1}.type='map';
OutCellArray{1}.header={'Date Created', ''; 'X size', num2str(2*max(xprof)); 'Y size', num2str(2*max(xprof)); 'X unit', xu; 'Y unit', yu; 'Z unit', zu;};


x=linspace(-1, 1, pts);
y=linspace(-1, 1, pts);
[x,y]=meshgrid(x*max(xprof),-1*y*max(xprof));
[~, rho] = cart2pol(x,y); %rhomap

map=zeros(size(rho,1),size(rho,2));

rho(rho>max(xprof))=NaN;
rho(rho<min(xprof))=NaN;

rhovec=unique(rho); %figure out where the z values need to be computed (which rho's exist)

rhovec(isnan(rhovec))=[];

radvec=interp1(xprof,zprof,rhovec); %compute z values at every point, from our profile

ul=max(xprof);
ll=min(xprof);

for ii=1:length(map(:)) %substitute in the appopriate z for the rho at each point
    if rho(ii)<=ul&&rho(ii)>=ll
        map(ii)=radvec(rhovec==rho(ii));
    else
        map(ii)=NaN;
    end
end

OutCellArray{1}.data=map;

end

